const conf = new JsonConfigFile("./plugins/SimpleBanCmd/config.json");
const config = conf.init("config", {
    "Prefix": "§r[§aSimpleBanCmd§r] ", // 插件提示前缀
    "ban_execute": false, // 是否禁用execute 注此插件是针对普通玩家的 所以execute一般来说不需要禁用
});

const DATA = new JsonConfigFile("./plugins/SimpleBanCmd/data.json");
DATA.init("list", []);

const Prefix = config.Prefix;
const Ban_execute = config.ban_execute;

/**
 * 管理命令禁用或解除禁用的函数
 *
 * @param {string} cmd - 要禁用或启用的命令
 * @param {boolean} or - 如果为 true，则禁用命令；如果为 false，则解除禁用命令
 * @param {Player} pla - 玩家对象
 * @returns {void}
 */
function bancmd(cmd, or, pla) {
    let cmdlist = DATA.get("list");

    if (or) {
        // 禁用命令
        if (cmdlist.includes(cmd)) return pla.tell("此命令已被禁用"); // 命令已被禁用
        // 禁用命令
        cmdlist.unshift(cmd);
        pla.tell("§c已禁用§f /" + cmd);
    } else {
        // 解除被禁用的命令
        if (!cmdlist.includes(cmd)) return pla.tell("§c此命令未被禁用"); // 命令未被禁用
        // 解除禁用命令
        cmdlist = cmdlist.filter(cmdItem => cmdItem !== cmd);
        pla.tell("已解除禁用§f /" + cmd);
    }

    DATA.set("list", cmdlist); // 写入数据
}

mc.listen("onServerStarted", () => {
    // 注册命令
    const BANCMD = mc.newCommand("simplebancmd", "SimpleBanCmd", PermType.GameMasters, 0x80, "sbc");
    BANCMD.setEnum("banlist", ["banlist"]);
    BANCMD.setEnum("cmd", ["unban", "ban"]);
    BANCMD.mandatory("cmds", ParamType.Command);
    BANCMD.mandatory("banlist", ParamType.Enum, "banlist", 1);
    BANCMD.mandatory("cmd", ParamType.Enum, "cmd", 1);
    BANCMD.overload(["cmd", "cmds"]);
    BANCMD.overload(["banlist"]);
    BANCMD.setCallback((_cmd, ori, _out, res) => {
        let pla = ori.player;
        switch (res.cmd) {
            case "unban": bancmd(res.cmds, false, pla); break;
            case "ban": bancmd(res.cmds, true, pla); break;
        }
        if (res.banlist != "banlist") return; // 如果不是查看禁用列表命令，则返回
        if (DATA.get("list").length === 0) {
            return pla.tell("目前没有命令被禁用"); // 如果没有命令被禁用，返回提示信息
        } else pla.tell("被禁用的命令有：\n" + DATA.get("list").join(", ")); // 返回命令禁用列表
    });
    BANCMD.setup();

    // 插件启用提示
    logger.log("插件加载成功！版本：1.0.0");
    logger.log("作者：xiaotong");
});

mc.listen("onPlayerCmd", (player, cmd) => {
    if (Ban_execute == 1 && cmd == "execute") {
        player.tell("§cexecute命令已被禁用")
        return true
    }

    if (DATA.get("list").includes(cmd) ) {
        player.tell("§c此命令已被禁用")
        return false
    }
})

mc.listen("onCmdBlockExecute", (cmd, pos, isMinecart) => {
    if (Ban_execute == 1 && cmd == "execute") {
        return true
    }

    if (DATA.get("list").includes(cmd)) {
        return false
    }
})
